@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::ServerInfo;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 sub register {
   my ($self, $app) = @_;
@@ -13,6 +13,58 @@ sub register {
 
 1;
 
+=head1 NAME
+
+Mojolicious::Plugin::ServerInfo - display Server and Perl environment data
+
+=for html
+<a href="https://travis-ci.org/wollmers/Mojolicious-Plugin-ServerInfo"><img src="https://travis-ci.org/wollmers/Mojolicious-Plugin-ServerInfo.png" alt="Mojolicious-Plugin-ServerInfo"></a>
+<a href='https://coveralls.io/r/wollmers/Mojolicious-Plugin-ServerInfo?branch=master'><img src='https://coveralls.io/repos/wollmers/Mojolicious-Plugin-ServerInfo/badge.png?branch=master' alt='Coverage Status' /></a>
+
+=head1 SYNOPSIS
+
+ $app->plugin('Mojolicious::Plugin::ServerInfo');
+
+
+=head1 DESCRIPTION
+
+L<Mojolicious::Plugin::ServerInfo> is a Mojolicious-Plugin.
+
+It creates a route
+
+  /serverinfo
+  
+where detailed info is dispalyed in formatted HTML.
+
+
+=head1 SEE ALSO
+
+=over
+
+=item *
+
+L<Mojolicious>
+
+=back
+
+=head1 SOURCE REPOSITORY
+
+L<http://github.com/wollmers/Mojolicious-Plugin-ServerInfo>
+
+=head1 AUTHOR
+
+Helmut Wollmersdorfer, E<lt>helmut.wollmersdorfer@gmail.comE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2013-2015 by Helmut Wollmersdorfer
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
+
+
 __DATA__
 
 @@ serverinfo.css
@@ -155,56 +207,6 @@ th {
 </body>
 </html>
 
-@@ serverinfo.pod
-
-=head1 NAME
-
-Mojolicious::Plugin::ServerInfo - display Server and Perl environment data
-
-=for html
-<a href="https://travis-ci.org/wollmers/Mojolicious-Plugin-ServerInfo"><img src="https://travis-ci.org/wollmers/Mojolicious-Plugin-ServerInfo.png" alt="Mojolicious-Plugin-ServerInfo"></a>
-<a href='https://coveralls.io/r/wollmers/Mojolicious-Plugin-ServerInfo?branch=master'><img src='https://coveralls.io/repos/wollmers/Mojolicious-Plugin-ServerInfo/badge.png?branch=master' alt='Coverage Status' /></a>
-
-=head1 SYNOPSIS
-
- $app->plugin('Mojolicious::Plugin::ServerInfo');
+__END__
 
 
-=head1 DESCRIPTION
-
-L<Mojolicious::Plugin::ServerInfo> is a Mojolicious-Plugin.
-
-It creates a route
-
-  /serverinfo
-  
-where detailed info is dispalyed in formatted HTML.
-
-
-=head1 SEE ALSO
-
-=over
-
-=item *
-
-L<Mojolicious>
-
-=back
-
-=head1 SOURCE REPOSITORY
-
-L<http://github.com/wollmers/Mojolicious-Plugin-ServerInfo>
-
-=head1 AUTHOR
-
-Helmut Wollmersdorfer, E<lt>helmut.wollmersdorfer@gmail.comE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2013-2015 by Helmut Wollmersdorfer
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=cut
-
